<?php

namespace App\Http\Controllers\Admin;
use Illuminate\Support\str;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Carbon\Carbon;
use Image;


class FilmController extends Controller
{
    public function films(){

    	$films = \App\Film::orderBy('date_add_str', 'desc')->paginate(35);
    	
        return view('admin.films', ['films' => $films]);
    }

    public function film($titre){

    	$film   = \App\Film::where('slug', $titre)->first();

    	$server_vf_list     = explode("\n", $film->server_vf);
        $server_vostfr_list = explode("\n", $film->server_vostfr);
        $server_vo_list     = explode("\n", $film->server_vo);


        $server_vf = array();
        $server_vostfr = array();
        $server_vo = array();

        foreach ($server_vf_list as $value) {
            $server_vf[str::get_server_name($value)] = $value;
        }

        foreach ($server_vostfr_list as $value) {
            $server_vostfr[str::get_server_name($value)] = $value;
        }

        foreach ($server_vo_list as $value) {
            $server_vo[str::get_server_name($value)] = $value;
        }

        Carbon::setLocale('fr');

        $d_vostfr = Carbon::createFromFormat('Y-m-d H:i:s', $film->date_add_vostfr);
        $date_vostfr = $d_vostfr->diffForHumans();
        $d_vf = Carbon::createFromFormat('Y-m-d H:i:s', $film->date_add_vf);
        $date_vf = $d_vf->diffForHumans();
        $d_vo = Carbon::createFromFormat('Y-m-d H:i:s', $film->date_add_vo);
        $date_vo = $d_vo->diffForHumans();

       
    	return view('admin.film',[
    		                        'film'    => $film,
    		                        'server_vostfr' => $server_vostfr,
                                    'server_vf' => $server_vf,
                                    'server_vo' => $server_vo,
                                    'date_vostfr'  => $date_vostfr,
                                    'date_vf'  => $date_vf,
                                    'date_vo'  => $date_vo 
    	                    ]);

    }

    public function add_server_film(Request $request){

        $request->validate([
            'lang' => 'required|min:2|max:6',
            'qualite' => 'required|min:2',
            'server_link' => 'required|min:10',
        ]);

        $film = \App\Film::find($request->film_id);
        $film->qualite = $request->qualite;


        if ($request->lang == 'vostfr'){

            $film->server_vostfr = $request->server_link;
            $film->date_add_vostfr = Carbon::now();

        }elseif ($request->lang == 'vf') {

            $film->server_vf = $request->server_link;
            $film->date_add_vf = Carbon::now();

        }elseif ($request->lang == 'vo') {

            $film->server_vo = $request->server_link;
            $film->date_add_vo = Carbon::now();

        }else{

            return response()->json(json_encode(['statu'=> 'error', 'message' => 'invalide lang']));

        }

        $film->save();
        return response()->json(json_encode(['statu'=> 'seccuss', 'message' => 'les server ajoute']));


    }

    public function edit_film(Request $request){
        $request->validate([
            'action' => 'required|min:2|max:9',
            'action_value' => 'required|min:2',
        ]);

        $film = \App\Film::find($request->film_id);

        if ($request->action == 'image'){

            $image = Image::make($request->action_value)
                        ->resize(256,326)
                        ->encode('jpg');

            Storage::disk('public')->put('/public/image/film/'.$film->slug.'.jpg', $image);

        }elseif ($request->action == 'date') {

            $date = strtotime($request->action_value);

            $date_formated = date('Y-m-d', $date);

            $film->date_de_sortie = $date_formated;

        }elseif ($request->action == 'synopsis') {

            $film->synopsis = $request->action_value;

        }elseif ($request->action == 'org_titre') {

            $film->org_titre = $request->action_value;

        }else{

            return response()->json(json_encode(['statu'=> 'error', 'message' => 'invalide action']));

        }

        $film->save();
        return response()->json(json_encode(['statu'=> 'seccuss', 'message' => 'les detaille ajoute']));

    }

    public function show_hid_film(Request $request){
        $request->validate([
            'action_value' => 'required|min:2|max:9',
            'action' => 'required|min:2',
        ]);

        $boul = 0;

        $film = \App\Film::find($request->film_id);

        if ($request->action == "show") {
            $boul = 1;
        }elseif ($request->action == 'hid') {
            $boul = 0;
        }else{
            return response()->json(json_encode(['statu'=> 'error', 'message' => 'invalide action']));
        }

        if ($request->action_value == "box_offic") {
            $film->is_box_offic = $boul;
        }elseif ($request->action_value == "home") {
            $film->is_show_home = $boul;
        }else{
            return response()->json(json_encode(['statu'=> 'error', 'message' => 'invalide action value']));
        }

        $film->date_add_str = Carbon::now();

        $film->save();

        return response()->json(json_encode(['statu'=> 'seccuss', 'message' => 'le film est visible']));

    }

    public function delete_film(Request $request){
        $film = \App\Film::find($request->film_id);
        $film->delete();

        return response()->json(json_encode(['statu'=> 'seccuss', 'message' => 'le film est delete']));
    }
}
