<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\str;
use Image;
use Allocine\Api_allocine_helper;
use Tmdb\Laravel\Facades\Tmdb;


class IndexController extends Controller
{
    public function index(){
    	return view('admin.index');
    }


    public function add_film(Request $request){
    	$request->validate([
            'titre' => 'unique:films',
            'image' => 'image|mimes:jpeg,png,jpg|max:2048',
            'synopsis' => '',
        ]);


        if ($request->genre !=null) {
            $genres = explode(',', $request->genre);
        }else{
            $genres = array();
        }

        if ($request->pay !=null) {
            $pays = explode(',', $request->pay);
        }else{
            $pays = array();
        }

        if ($request->acteur !=null) {
            $acteurs = explode(',', $request->acteur);
        }else{
            $acteurs = array();
        }

        if ($request->createur !=null) {
            $createurs = explode(',', $request->createur);
        }else{
            $createurs = array();
        }

        $film =  \App\Film::firstOrNew(['slug' => str::urlSlug($request->titre)]);

        $film->titre          = $request->titre;
        $film->slug           = str::urlSlug($request->titre);
        $film->org_titre      = $request->org_titre;

        $date = strtotime($request->date_de_sortie);

        $date_formated = date('Y-m-d', $date);

        $film->date_de_sortie = $date_formated;

        $film->image          = '/public/image/film/'.str::urlSlug($request->titre).'.jpg';

        $film->synopsis       = $request->synopsis;

        $film->save();

        foreach ($genres as $value) {

        	$genre = \App\Genre::firstOrCreate(
                                        ['slug' => str::urlSlug($value)], ['titre' => $value]
                                    );

        	$film_genre = new \App\Film_genre();
        	$film_genre->film_id = $film->id;
        	$film_genre->genre_id = $genre->id;
        	$film_genre->save();

        }

        foreach ($pays as $value) {
        	
        	$pay = \App\Pay::firstOrCreate(
                                        ['slug' => str::urlSlug($value)], ['titre' => $value]
                                    );

        	$film_pay = new \App\Film_pay();
        	$film_pay->film_id = $film->id;
        	$film_pay->pay_id = $pay->id;
        	$film_pay->save();

        }

        foreach ($acteurs as $value) {
        	
        	$acteur = \App\Acteur::firstOrCreate(
                                        ['slug' => str::urlSlug($value)], ['titre' => $value]
                                    );

        	$film_acteur = new \App\Film_acteur();
        	$film_acteur->film_id = $film->id;
        	$film_acteur->acteur_id = $acteur->id;
        	$film_acteur->save();

        }

        foreach ($createurs as $value) {
        	
        	$createur = \App\Createur::firstOrCreate(
                                        ['slug' => str::urlSlug($value)], ['titre' => $value]
                                    );

        	$film_createur = new \App\Film_createur();
        	$film_createur->film_id = $film->id;
        	$film_createur->createur_id = $createur->id;
        	$film_createur->save();

        }

        if ($request->file('image') != null) {
            $photo = Image::make($request->file('image'))
                        ->resize(256,326)
                        ->encode('jpg');

            Storage::disk('public')->put('/public/image/film/'.str::urlSlug($request->titre).'.jpg', $photo);

        }
        
        return back()->with('status', 'seccuss');

    }


    public function add_serie(Request $request){
    	$request->validate([
    	    'titre' => 'unique:series',
            'image' => 'image|mimes:jpeg,png,jpg|max:2048',
            'synopsis' => '',
        ]);



        if ($request->genre !=null) {
            $genres = explode(',', $request->genre);
        }else{
            $genres = array();
        }

        if ($request->pay !=null) {
            $pays = explode(',', $request->pay);
        }else{
            $pays = array();
        }

        if ($request->acteur !=null) {
            $acteurs = explode(',', $request->acteur);
        }else{
            $acteurs = array();
        }

        if ($request->createur !=null) {
            $createurs = explode(',', $request->createur);
        }else{
            $createurs = array();
        }

        

        $serie =  \App\Serie::firstOrNew(['slug' => str::urlSlug($request->titre)]);

        $serie->titre          = $request->titre;
        $serie->slug           = str::urlSlug($request->titre);
        $serie->org_titre      = $request->org_titre;

        $serie->annee = $request->annee;

        $serie->synopsis       = $request->synopsis;

        $serie->save();

        $saison = new \App\Saison([
        	            "saison" => 1,
        	            "image" => "/public/image/serie/".str::urlSlug($request->titre)."-saison-1.jpg"
        	        ]);

        $serie->saisons()->save($saison);

        foreach ($genres as $value) {

        	$genre = \App\Genre::firstOrCreate(
                                        ['slug' => str::urlSlug($value)], ['titre' => $value]
                                    );

        	$serie_genre = new \App\Serie_genre();
        	$serie_genre->serie_id = $serie->id;
        	$serie_genre->genre_id = $genre->id;
        	$serie_genre->save();

        }

        foreach ($pays as $value) {
        	
        	$pay = \App\Pay::firstOrCreate(
                                        ['slug' => str::urlSlug($value)], ['titre' => $value]
                                    );

        	$serie_pay = new \App\Serie_pay();
        	$serie_pay->serie_id = $serie->id;
        	$serie_pay->pay_id = $pay->id;
        	$serie_pay->save();

        }

        foreach ($acteurs as $value) {
        	
        	$acteur = \App\Acteur::firstOrCreate(
                                        ['slug' => str::urlSlug($value)], ['titre' => $value]
                                    );

        	$serie_acteur = new \App\Serie_acteur();
        	$serie_acteur->serie_id = $serie->id;
        	$serie_acteur->acteur_id = $acteur->id;
        	$serie_acteur->save();

        }

        foreach ($createurs as $value) {
        	
        	$createur = \App\Createur::firstOrCreate(
                                        ['slug' => str::urlSlug($value)], ['titre' => $value]
                                    );

        	$serie_createur = new \App\Serie_createur();
        	$serie_createur->serie_id = $serie->id;
        	$serie_createur->createur_id = $createur->id;
        	$serie_createur->save();

        }
        if ($request->file('image') != null) {
            $photo = Image::make($request->file('image'))
                        ->resize(256,326)
                        ->encode('jpg');

            Storage::disk('public')->put("/public/image/serie/".str::urlSlug($request->titre)."-saison-1.jpg", $photo);
        }

        return back()->with('status', 'seccuss');

    }

    public function add_film_serie_from_allonice(Request $request){
        $validate = $request->validate([
            'link' => 'required|min:2',
            'type' => 'required|min:2'
        ]);
        $link = $request->link;
        $type = $request->type;
        $data = (new Api_allocine_helper($link, $type))->getData();

        if ($request->type == 'film') {
            
            if(\App\Film::where('slug', str::urlSlug(strip_tags($data['title'])))->exists()){
                return "le film est dija exist";
            }

            $film =  \App\Film::firstOrNew(['slug' => str::urlSlug(strip_tags($data['title']))]);

            $film->titre          = strip_tags($data['title']);
            $film->slug           = str::urlSlug(strip_tags($data['title']));
            $film->org_titre      = strip_tags($data['originalTitle']);

            //$date_formated = date('Y-m-d', $data['release']['releaseDate']);

            $film->date_de_sortie = isset($data['release']['releaseDate']) ? $data['release']['releaseDate']: '';

            $film->image          = '/public/image/film/'.str::urlSlug(strip_tags($data['title'])).'.jpg';

            $film->synopsis       = isset($data['synopsisShort']) ? strip_tags($data['synopsisShort']): '';

           $film->save();

            foreach ($data['genre'] as $value) {
       
                $genre = \App\Genre::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['$']))], ['titre' => strip_tags($value['$'])]
                                        );

                $film_genre = new \App\Film_genre();
                $film_genre->film_id = $film->id;
                $film_genre->genre_id = $genre->id;
                $film_genre->save();

            }

            foreach ($data['nationality'] as $value) {
            
                $pay = \App\Pay::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['$']))], ['titre' => strip_tags($value['$'])]
                                        );

                $film_pay = new \App\Film_pay();
                $film_pay->film_id = $film->id;
                $film_pay->pay_id = $pay->id;
                $film_pay->save();

            }
            
            $acteurs = explode(',', strip_tags($data['castingShort']['actors']));
            $createurs = explode(',', strip_tags($data['castingShort']['directors']));

            foreach ($acteurs as $value) {
            
                $acteur = \App\Acteur::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value))], ['titre' => strip_tags($value)]
                                        );

            $film_acteur = new \App\Film_acteur();
            $film_acteur->film_id = $film->id;
            $film_acteur->acteur_id = $acteur->id;
            $film_acteur->save();

            }

            foreach ($createurs as $value) {
            
                $createur = \App\Createur::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value))], ['titre' => strip_tags($value)]
                                        );

                $film_createur = new \App\Film_createur();
                $film_createur->film_id = $film->id;
                $film_createur->createur_id = $createur->id;
                $film_createur->save();

            }

            $photo = Image::make($data['poster']->imageUrl())
                            ->resize(256,326)
                            ->encode('jpg');

                Storage::disk('public')->put('/public/image/film/'.str::urlSlug(strip_tags($data['title'])).'.jpg', $photo);

            return back()->with('status', 'seccuss');


        }elseif ($request->type == 'serie') {
            if(\App\Serie::where('slug', str::urlSlug(strip_tags($data['title'])))->exists()){
                return "la series est dija exist";
            }

            $serie =  \App\Serie::firstOrNew(['slug' => str::urlSlug(strip_tags($data['title']))]);
           
            $serie->titre          = strip_tags($data['title']);
            $serie->slug           = str::urlSlug(strip_tags($data['title']));
            $serie->org_titre      = strip_tags($data['originalTitle']);

            //$date_formated = date('Y-m-d', $data['release']['releaseDate']);

            $serie->annee = $data['yearStart'];

            $serie->synopsis       = isset($data['synopsisShort']) ? strip_tags($data['synopsisShort']): '';

            $serie->save();

                $saison = new \App\Saison([
                        "saison" => 1,
                        "image" => "/public/image/serie/".str::urlSlug(strip_tags($data['title']))."-saison-1.jpg"
                    ]);

                $serie->saisons()->save($saison);

            foreach ($data['genre'] as $value) {
       
                $genre = \App\Genre::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['$']))], ['titre' => strip_tags($value['$'])]
                                        );

                $serie_genre = \App\Serie_genre::firstOrCreate([
                                            'serie_id' => $serie->id,
                                            'genre_id'=> $genre->id
                                        ]);

            }

            foreach ($data['nationality'] as $value) {
            
                $pay = \App\Pay::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['$']))], ['titre' => strip_tags($value['$'])]
                                        );

                $serie_pay = \App\Serie_pay::firstOrCreate([
                                            'serie_id' => $serie->id,
                                            'pay_id'=> $pay->id
                                        ]);

            }
            
            if(isset($data['castingShort']['actors'])){
                $acteurs = explode(',', strip_tags($data['castingShort']['actors']));
            }else{
                $acteurs = array();
            }
            
            
            if(isset($data['castingShort']['creators'])){
                $createurs = explode(',', strip_tags($data['castingShort']['creators']));
            }else{
                $createurs = array();
            }
            

            foreach ($acteurs as $value) {
            
                $acteur = \App\Acteur::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value))], ['titre' => strip_tags($value)]
                                        );

            $serie_acteur = \App\Serie_acteur::firstOrCreate([
                                            'serie_id' => $serie->id,
                                            'acteur_id'=> $acteur->id
                                        ]);

            }

            foreach ($createurs as $value) {
            
                $createur = \App\Createur::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value))], ['titre' => strip_tags($value)]
                                        );

                $serie_createur = \App\Serie_createur::firstOrCreate([
                                            'serie_id' => $serie->id,
                                            'createur_id'=> $createur->id
                                        ]);

            }

            $photo = Image::make($data['poster']['href'])
                            ->resize(256,326)
                            ->encode('jpg');

                Storage::disk('public')->put("/public/image/serie/".str::urlSlug(strip_tags($data['title']))."-saison-1.jpg", $photo);

            return back()->with('status', 'seccuss');
        }
        
    }
    
    public function add_film_serie_from_tmdb(Request $request){
        $validate = $request->validate([
            'link' => 'required|min:2',
            'type' => 'required|min:2'
        ]);
        
        if($request->type == 'serie'){
            $id = explode('/tv/',$request->link);
        
            $id = explode('-', $id[1]);
        
            $id = explode('?', $id[0]);
        
            $id = $id[0];
        
        
            $data = Tmdb::getTvApi()->getTvshow($id);

            $cast = Tmdb::getTvApi()->getCredits($id)['cast'];
            dd($data);

            if(\App\Serie::where('slug', str::urlSlug(strip_tags($data['name'])))->exists()){
                return "la series est dija exist";
            }

            $serie =  \App\Serie::firstOrNew(['slug' => str::urlSlug(strip_tags($data['name']))]);
           
            $serie->titre          = strip_tags($data['name']);
            $serie->slug           = str::urlSlug(strip_tags($data['name']));
            $serie->org_titre      = strip_tags($data['original_name']);
            
            $fdate = strtotime($data['first_air_date']);
            
            
            $serie->annee = date('Y',$fdate);

            $serie->synopsis       = strip_tags($data['overview']);

            $serie->save();

                $saison = new \App\Saison([
                        "saison" => 1,
                        "image" => "/public/image/serie/".str::urlSlug(strip_tags($data['name']))."-saison-1.jpg"
                    ]);

                $serie->saisons()->save($saison);

            foreach ($data['genres'] as $value) {
       
                $genre = \App\Genre::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['name']))], ['titre' => strip_tags($value['name'])]
                                        );

                $serie_genre = \App\Serie_genre::firstOrCreate([
                                            'serie_id' => $serie->id,
                                            'genre_id'=> $genre->id
                                        ]);

            }

            foreach ($data['origin_country'] as $value) {
            
                $pay = \App\Pay::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value))], ['titre' => strip_tags($value)]
                                        );

                $serie_pay = \App\Serie_pay::firstOrCreate([
                                            'serie_id' => $serie->id,
                                            'pay_id'=> $pay->id
                                        ]);

            }
            
            $acteurs = $cast;
            $createurs = $data['created_by'];

            foreach ($acteurs as $value) {
            
                $acteur = \App\Acteur::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['name']))], ['titre' => strip_tags($value['name'])]
                                        );

            $serie_acteur = \App\Serie_acteur::firstOrCreate([
                                            'serie_id' => $serie->id,
                                            'acteur_id'=> $acteur->id
                                        ]);

            }

            foreach ($createurs as $value) {
            
                $createur = \App\Createur::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['name']))], ['titre' => strip_tags($value['name'])]
                                        );

                $serie_createur = \App\Serie_createur::firstOrCreate([
                                            'serie_id' => $serie->id,
                                            'createur_id'=> $createur->id
                                        ]);

            }

            $photo = Image::make('https://image.tmdb.org/t/p/w300_and_h450_bestv2/'.$data['poster_path'])
                            ->resize(256,326)
                            ->encode('jpg');

                Storage::disk('public')->put("/public/image/serie/".str::urlSlug(strip_tags($data['name']))."-saison-1.jpg", $photo);

            return back()->with('status', 'seccuss');
        }else{
            
            
            $id = explode('/movie/',$request->link);
        
            $id = explode('-', $id[1]);
        
            $id = explode('?', $id[0]);
        
            $id = $id[0];
            
            $data = Tmdb::getMoviesApi()->getMovie($id);
            
            $cast = Tmdb::getMoviesApi()->getCredits($id)['cast'];
            
            
            if(\App\Film::where('slug', str::urlSlug(strip_tags($data['title'])))->exists()){
                return "le film est dija exist";
            }

            $film =  \App\Film::firstOrNew(['slug' => str::urlSlug(strip_tags($data['title']))]);

            $film->titre          = strip_tags($data['title']);
            $film->slug           = str::urlSlug(strip_tags($data['title']));
            $film->org_titre      = strip_tags($data['original_title']);

            //$date_formated = date('Y-m-d', $data['release']['releaseDate']);

            $film->date_de_sortie = isset($data['release_date']) ? $data['release_date']: '';

            $film->image          = '/public/image/film/'.str::urlSlug(strip_tags($data['title'])).'.jpg';

            $film->synopsis       = isset($data['overview']) ? strip_tags($data['overview']): '';

           $film->save();

            foreach ($data['genres'] as $value) {
       
                $genre = \App\Genre::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['name']))], ['titre' => strip_tags($value['name'])]
                                        );

                $film_genre = new \App\Film_genre();
                $film_genre->film_id = $film->id;
                $film_genre->genre_id = $genre->id;
                $film_genre->save();

            }

            foreach ($data['production_countries'] as $value) {
            
                $pay = \App\Pay::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['name']))], ['titre' => strip_tags($value['name'])]
                                        );

                $film_pay = new \App\Film_pay();
                $film_pay->film_id = $film->id;
                $film_pay->pay_id = $pay->id;
                $film_pay->save();

            }
            
            $acteurs = $cast;
            $createurs = [];
            
            $i = 0;
            foreach ($acteurs as $value) {
            
                $acteur = \App\Acteur::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value['name']))], ['titre' => strip_tags($value['name'])]
                                        );

            $film_acteur = new \App\Film_acteur();
            $film_acteur->film_id = $film->id;
            $film_acteur->acteur_id = $acteur->id;
            $film_acteur->save();
            
            $i++;
            if($i == 5) break;

            }

            foreach ($createurs as $value) {
            
                $createur = \App\Createur::firstOrCreate(
                                            ['slug' => str::urlSlug(strip_tags($value))], ['titre' => strip_tags($value)]
                                        );

                $film_createur = new \App\Film_createur();
                $film_createur->film_id = $film->id;
                $film_createur->createur_id = $createur->id;
                $film_createur->save();

            }

            $photo = Image::make('https://image.tmdb.org/t/p/w300_and_h450_bestv2/'.$data['poster_path'])
                            ->resize(256,326)
                            ->encode('jpg');

                Storage::disk('public')->put('/public/image/film/'.str::urlSlug(strip_tags($data['title'])).'.jpg', $photo);

            return back()->with('status', 'seccuss');
        }
    }
}
