<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\str;
use Carbon\Carbon;
use Illuminate\Support\Facades\Cache;

class FilmController extends Controller
{
    public function films($page = 1){
    	
    	$films = \App\Film::where(function($query){
                                            $query->whereRaw('server_vostfr IS NOT null')
                                                  ->orWhereRaw('server_vf IS NOT null')
                                                  ->orWhereRaw('server_vo IS NOT null');
                                            })->orderBy('date_add_str', 'desc')->paginate(18, ['*'], 'page', $page);
    	
        return view('film.films', ['films' => $films]);
    }

    public function genre($genre, $page = 1){
        
        $films = \App\Genre::where('slug', $genre)->first()
                            ->film_genres()->whereHas('film', function ($query) {
                                    $query->where(function($query){
                                            $query->whereRaw('server_vostfr IS NOT null')
                                                  ->orWhereRaw('server_vf IS NOT null')
                                                  ->orWhereRaw('server_vo IS NOT null');
                                              });
                            })->orderBy('id', 'desc')
                            ->paginate(18, ['*'], 'page', $page);


        $genre = \App\Genre::where('slug', $genre)->first();

        return view('film.genrefilms',['films' => $films, 'genre' => $genre]);
    }

    public function createur($createur, $page = 1){
        
        $films = \App\Createur::where('slug', $createur)->first()
                            ->film_createurs()->whereHas('film' , function ($query) {
                                    $query->where(function($query){
                                            $query->whereRaw('server_vostfr IS NOT null')
                                                  ->orWhereRaw('server_vf IS NOT null')
                                                  ->orWhereRaw('server_vo IS NOT null');
                                              });
                            })->orderBy('id', 'desc')
                            ->paginate(20, ['*'], 'page', $page);
                            

        $createur = \App\Createur::where('slug', $createur)->first()->titre;

        return view('film.createurfilms',['films' => $films, 'createur' => $createur]);

    }


    public function acteur($acteur, $page = 1){
        
        $films = \App\Acteur::where('slug', $acteur)->first()
                            ->film_acteurs()->whereHas('film', function ($query) {
                                    $query->where(function($query){
                                            $query->whereRaw('server_vostfr IS NOT null')
                                                  ->orWhereRaw('server_vf IS NOT null')
                                                  ->orWhereRaw('server_vo IS NOT null');
                                              });
                            })->orderBy('id', 'desc')
                            ->paginate(20, ['*'], 'page', $page);

        $acteur = \App\Acteur::where('slug', $acteur)->first()->titre;

        return view('film.acteurfilms',['films' => $films, 'acteur' => $acteur]);

    }

    public function pay($pay, $page = 1){
       
        $films = \App\Pay::where('slug', $pay)->first()
                            ->film_pays()->whereHas('film', function ($query) {
                                    $query->where(function($query){
                                            $query->whereRaw('server_vostfr IS NOT null')
                                                  ->orWhereRaw('server_vf IS NOT null')
                                                  ->orWhereRaw('server_vo IS NOT null');
                                              });
                            })->orderBy('id', 'desc')
                            ->paginate(20, ['*'], 'page', $page);

        $pay = \App\Pay::where('slug', $pay)->first()->titre;


        return view('film.payfilms',['films' => $films, 'pay' => $pay]);

    }

    public function date($date, $page = 1){
        $films = \App\Film::whereYear('date_de_sortie', $date)->where(function($query){
                                            $query->whereRaw('server_vostfr IS NOT null')
                                                  ->orWhereRaw('server_vf IS NOT null')
                                                  ->orWhereRaw('server_vo IS NOT null');
                            })->orderBy('id', 'desc')
                            ->paginate(20, ['*'], 'page', $page);


        return view('film.datefilms',['films' => $films, 'date' => $date]);

    }


    public function film($titre){

        $autfilms = Cache::remember('autfilms', Carbon::now()->addDays(3), function () {
            return \App\Film::where('is_show_home', 1)
                            ->inRandomOrder()->limit(8)->get();
        });


    	$film   = \App\Film::where('slug', $titre)->first();

    	$server_vf_list     = explode("\n", $film->server_vf);
        $server_vostfr_list = explode("\n", $film->server_vostfr);
        $server_vo_list     = explode("\n", $film->server_vo);


        $server_vf = array();
        $server_vostfr = array();
        $server_vo = array();

        foreach ($server_vf_list as $value) {
            $server_vf[str::get_server_name($value)] = $value;
        }

        foreach ($server_vostfr_list as $value) {
            $server_vostfr[str::get_server_name($value)] = $value;
        }

        foreach ($server_vo_list as $value) {
            $server_vo[str::get_server_name($value)] = $value;
        }

        Carbon::setLocale('fr');

        //$d_in_vostfr = (new \DateTime($film->date_add_vostfr))->format('Y-m-d h:m:s');

        $d_vostfr = Carbon::createFromFormat('Y-m-d H:i:s', $film->date_add_vostfr);
        $date_vostfr = $d_vostfr->diffForHumans();
        $d_vf = Carbon::createFromFormat('Y-m-d H:i:s', $film->date_add_vf);
        $date_vf = $d_vf->diffForHumans();
        $d_vo = Carbon::createFromFormat('Y-m-d H:i:s', $film->date_add_vo);
        $date_vo = $d_vo->diffForHumans();



    	return view('film.film',[
                                    'autfilms'    => $autfilms,
    		                        'film'    => $film,
    		                        'server_vf' => $server_vf,
                                    'server_vostfr' => $server_vostfr,
                                    'server_vo' => $server_vo,
                                    'date_vf'  => $date_vf,
                                    'date_vostfr'  => $date_vostfr,
                                    'date_vo'  => $date_vo 
    	                    ]);

    }
    
    
    public function custom(Request $request){
        $html = '';

        $genre = $request->genre;
    if($genre != ""){
        $films = \App\Genre::where('slug', $genre)->first()
                            ->film_genres()->whereHas('film', function ($query) {
                                    $query->where('is_box_offic', 1)->where(function($query){
                                            return $query->whereNotNull('server_vf')
                                                ->orWhereNotNull('server_vostfr')
                                                ->orWhereNotNull('server_vo');
                                            });
                            })->orderBy('id', 'desc')
                            ->limit(6)->get();
        foreach($films as $film){
            
            $qualite = $film->film->qualite;
            $mqualite = $qualite == 'Bdrip' ? '720P': $qualite;
            $html.='
            <div class="short">
                <div class="short-in nl">
                <span class="film-verz"><a href="#">DE</a> </span>
                <span class="film-ripz"><a href="#">'.$mqualite.'</a></span>
                    <a class="short-poster img-box with-mask" href="'.route('film', ['titre'=> $film->film->slug ]).'" alt="'.$film->film->titre.' stream deutsch">
                        <img src="/posters'.$film->film->image.'" alt="'.$film->film->titre.' stream deutsch" width="160" height="240">
                        <div class="short-mask fx-col fx-center fx-middle">
                            <span class="fa fa-play-circle"></span>
                        </div>
                        <div class="vue">
                        </div>
                        <div class="short-title"> '.$film->film->titre.' </div>
                    </a>
                    <div style="position:absolute;top:91%;right:0px;z-index: 66;"> </div>
                </div>
            </div>
            ';
        }
        }else{
            $films = \App\Film::where('is_box_offic', 1)->where(function($query){
                            return $query->whereNotNull('server_vf')
                                            ->orWhereNotNull('server_vostfr')
                                            ->orWhereNotNull('server_vo');
                                })->orderBy('date_add_str', 'desc')
                                ->limit(6)->get();
            
            foreach($films as $film){
                $qualite = $film->qualite;
                $mqualite = $qualite == 'Bdrip' ? '720P': $qualite;
            $html.='
            <div class="short">
                <div class="short-in nl">
                <span class="film-verz"><a href="#">DE</a> </span>
                <span class="film-ripz"><a href="#">'.$mqualite.'</a></span>
                    <a class="short-poster img-box with-mask" href="'.route('film', ['titre'=> $film->slug ]).'" alt="'.$film->titre.' stream deutsch">
                        <img src="/posters'.$film->image.'" alt="'.$film->titre.' stream deutsch" width="160" height="240">
                        <div class="short-mask fx-col fx-center fx-middle">
                            <span class="fa fa-play-circle"></span>
                        </div>
                        <div class="vue">
                        </div>
                        <div class="short-title"> '.$film->titre.' </div>
                    </a>
                    <div style="position:absolute;top:91%;right:0px;z-index: 66;"> </div>
                </div>
            </div>
            ';
        }
    }
        return response($html, 200)->header('Content-Type', 'text/html');

    }
    
}
