<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\str;
use Carbon\Carbon;
use Illuminate\Support\Facades\Cache;
use Illuminate\Database\Eloquent\Builder;
 

class SerieController extends Controller
{

    public function series($page = 1){
        
        $saisons  = \App\Saison::whereHas('episodes', function($query){
                                $query->whereNotNull('server_vf')->orWhereNotNull('server_vostfr');
                                 })
                                ->orderBy('id', 'desc')
                                ->paginate(18, ['*'], 'page', $page);
        return view('serie.series',[
            'saisons' => $saisons
        ]);
    }

    public function topSeries($page = 1){
        
        $series  = \App\Serie::whereHas('saisons')
                                ->where('is_top', 1)
                                ->orderBy('date_add_str', 'desc')
                                ->paginate(20, ['*'], 'page', $page);


        return view('serie.topseries',['series' => $series]);
    }


    public function netflixSeries($page = 1){
        
        $series  = \App\Serie::whereHas('saisons')
                                ->where('is_top', 1)
                                ->orderBy('date_add_str', 'desc')
                                ->paginate(20, ['*'], 'page', $page);


        return view('serie.netflixseries',['series' => $series]);
    }




    public function serie($titre){
        
        $serie = \App\Serie::where('slug', $titre)->first();

        $autSeries = Cache::remember('autSeries', Carbon::now()->addDays(1), function () {
            return \App\Serie::whereHas('saisons')
                            ->where('is_show', 1)
                            ->orderBy('id', 'desc')
                            ->inRandomOrder()->limit(4)->get();
        });
        
    	return view('serie.serie', ['serie' => $serie, 'autSeries' => $autSeries]);
    }



    public function saison($titre, $saison, $id){
        $saison = \App\Saison::find($id);
        
/*        $autSeries = Cache::remember('autSeries2', Carbon::now()->addDays(1), function () {
            return \App\Serie::whereHas('saisons')
                            ->where('is_show', 1)
                            ->orderBy('id', 'desc')
                            ->inRandomOrder()->limit(10)->get();
        });
*/
        $episode_vf = $saison->episodes()->whereRaw('server_vf IS NOT null')->orderBy('episode')->get();
        $episode_vostfr = $saison->episodes()->whereRaw('server_vostfr IS NOT null')->orderBy('episode')->get();
        
                            
    	return view('serie.saison', ['saison' => $saison, 'episode_vf' => $episode_vf, 'episode_vostfr' => $episode_vostfr]);
    }



    public function episode($titre, $saison, $episode, $id){

        $autSeries = \App\Serie::whereHas('saisons')
                            ->where('is_show', 1)
                            ->orderBy('id', 'desc')
                            ->limit(12)->get();


        $episode = \App\Episode::find($id);
        
        $serie = $episode->saison->serie;
        
        

        $server_vf_list     = explode("\n", $episode->server_vf);
        $server_vostfr_list = explode("\n", $episode->server_vostfr);
        $server_vo_list     = explode("\n", $episode->server_vo);

        $server_vf = array();
        $server_vostfr = array();
        $server_vo = array();

        foreach ($server_vf_list as $value) {
            $server_vf[str::get_server_name($value)] = $value;
        }

        foreach ($server_vostfr_list as $value) {
            $server_vostfr[str::get_server_name($value)] = $value;
        }

        foreach ($server_vo_list as $value) {
            $server_vo[str::get_server_name($value)] = $value;
        }

        Carbon::setLocale('fr');


        $d_vostfr = Carbon::createFromFormat('Y-m-d H:i:s', $episode->date_add_vostfr);
        $date_vostfr = $d_vostfr->diffForHumans();
        $d_vf = Carbon::createFromFormat('Y-m-d H:i:s', $episode->date_add_vf);
        $date_vf = $d_vf->diffForHumans();
        $d_vo = Carbon::createFromFormat('Y-m-d H:i:s', $episode->date_add_vo);
        $date_vo = $d_vo->diffForHumans();



        return view('serie.episode',[
                                    'episode'    => $episode,
                                    'serie'   => $serie,
                                    'server_vf' => $server_vf,
                                    'server_vostfr' => $server_vostfr,
                                    'server_vo' => $server_vo,
                                    'date_vf'  => $date_vf,
                                    'date_vostfr'  => $date_vostfr,
                                    'date_vo'  => $date_vo,
                                    'autSeries' => $autSeries
                            ]);
    }

    public function autre_episode(Request $request){
        $episode_id = $request->episode;
        $saison_id  = $request->saison;

        $episode  = \App\Episode::find($episode_id);
        $saison  = \App\Saison::find($saison_id);

        return redirect(route("episode",[
                                        'titre' => $saison->serie->slug,
                                        'saison' => $saison->saison,
                                        'episode' => $episode->episode,
                                        'id' => $episode->id
                                    ]));
    } 

    public function charge_episode(Request $request){
        $saison_id = $request->saison;
        $episodes = \App\Saison::find($saison_id)->episodes()->where(function($query){
                                            $query->whereRaw('server_vostfr IS NOT null')
                                                  ->orWhereRaw('server_vf IS NOT null')
                                                  ->orWhereRaw('server_vo IS NOT null');
                                            })->get();
        $html = '';
 
        foreach ($episodes as $episode) {
            $html .= '<option value='.$episode->id.'>Episode '.$episode->episode.'</option>';
        }

        return response($html, 200)->header('Content-Type', 'text/html');
    }


    public function custom(Request $request){
        $html = '';

        $genre = $request->genre;
    if($genre != ""){
        $series = \App\Genre::where('slug',$genre)->first()
                            ->serie_genres()->whereHas('serie', function ($query) {
                                    $query->where('is_show', 1);
                            })->orderBy('id', 'desc')
                            ->limit(6)->get();
        foreach($series as $serie){
            $lastSaison = $serie->serie->saisons()->get()->last();
            $last_episode = $lastSaison->episodes()->get()->last();
            $html.='
            <div class="short">
                <div class="short-in nl">
                <span class="film-verz"><a href="#">DE</a> </span>
                    <a class="short-poster img-box with-mask" href="'.route('saison', ['titre'=> $serie->serie->slug, 'saison' => $lastSaison->saison, 'id' => $lastSaison->id ]).'" alt="'.$serie->serie->titre.' staffel '.$lastSaison->saison.' stream deutsch">
                        <img src="/posters'.$lastSaison->image.'" alt="'.$serie->serie->titre.' staffel '.$lastSaison->saison.' stream deutsch" width="160" height="240">
                        <div class="short-mask fx-col fx-center fx-middle">
                            <span class="fa fa-play-circle"></span>
                        </div>
                        <div class="vue">
                        </div>
                        <span class="mli-eps">Folge<p></p><i>'.$last_episode->episode.'</i></span>
                        <div class="short-title"> '.$serie->serie->titre.' staffel '.$lastSaison->saison.' </div>
                    </a>
                    <div style="position:absolute;top:91%;right:0px;z-index: 66;"> </div>
                </div>
            </div>
            ';
        }
        }else{
            $series = \App\Serie::whereHas('saisons')->orderBy('date_add_str', 'desc')->where('is_top', 1)->limit(6)->get();
            
            foreach($series as $serie){
            $lastSaison = $serie->saisons()->get()->last();
            $last_episode = $lastSaison->episodes()->get()->last();
            $html.='
            <div class="short">
                <div class="short-in nl">
                <span class="film-verz"><a href="#">DE</a> </span>
                    <a class="short-poster img-box with-mask" href="'.route('saison', ['titre'=> $serie->slug, 'saison' => $lastSaison->saison, 'id' => $lastSaison->id ]).'" alt="'.$serie->titre.' staffel '.$lastSaison->saison.' stream deutsch">
                        <img src="/posters'.$lastSaison->image.'" alt="'.$serie->titre.' staffel '.$lastSaison->saison.' stream deutsch" width="160" height="240">
                        <div class="short-mask fx-col fx-center fx-middle">
                            <span class="fa fa-play-circle"></span>
                        </div>
                        <div class="vue">
                        </div>
                        <span class="mli-eps">Folge<p></p><i>'.$last_episode->episode.'</i></span>
                        <div class="short-title"> '.$serie->titre.' staffel '.$lastSaison->saison.' </div>
                    </a>
                    <div style="position:absolute;top:91%;right:0px;z-index: 66;"> </div>
                </div>
            </div>
            ';
        }
    }
        return response($html, 200)->header('Content-Type', 'text/html');

    }


    public function genre($genre, $page = 1){
    /*    $series = \App\Genre::where('slug', $genre)->first()
                            ->serie_genres()->whereHas('serie', function ($query) {
                                    $query->where('is_show', 1);
                            })->orderBy('id', 'desc')
                            ->paginate(20, ['*'], 'page', $page);

        $genre = \App\Genre::where('slug', $genre)->first();*/
        
        $genre = \App\Genre::where('slug', $genre)->first();

        $saisons = \App\Saison::whereHas('episodes', function($query){
                                $query->whereNotNull('server_vf')->orWhereNotNull('server_vostfr');
                                })->whereHas('serie',function(Builder $query) use($genre){
            $query->whereHas('serie_genre', function(Builder $query) use ($genre){
                $query->where('genre_id', $genre->id);
            });
        })->orderBy('date_add_str', 'desc')->paginate(18, ['*'], 'page', $page);

        return view('serie.genreseries',['saisons' => $saisons, 'genre' => $genre]);
    }

     public function createur($createur, $page = 1){
        $series = \App\Createur::where('slug', $createur)->first()
                            ->serie_createurs()->whereHas('serie', function ($query) {
                                    $query->where('is_show', 1);
                            })->orderBy('id', 'desc')
                            ->paginate(20, ['*'], 'page', $page);

        $createur = \App\Createur::where('slug', $createur)->first();


        return view('serie.createurseries',['series' => $series, 'createur' => $createur]);
    }




    public function acteur($acteur, $page = 1){
        $series = \App\Acteur::where('slug', $acteur)->first()
                            ->serie_acteurs()->whereHas('serie', function ($query) {
                                    $query->where('is_show', 1);
                            })->orderBy('id', 'desc')
                            ->paginate(20, ['*'], 'page', $page);

        $acteur = \App\Acteur::where('slug', $acteur)->first();

        return view('serie.acteurseries',['series' => $series, 'acteur' => $acteur]);
    }

    public function pay($pay, $page = 1){
        $series = \App\Pay::where('slug', $pay)->first()
                            ->serie_pays()->whereHas('serie', function ($query) {
                                    $query->where('is_show', 1);
                            })->orderBy('id', 'desc')
                            ->paginate(20, ['*'], 'page', $page);

        $pay  = \App\Pay::where('slug', $pay)->first();


        return view('serie.payseries',['series' => $series, 'pay' => $pay]);
    }


    public function date($date, $page = 1){
        $series  = \App\Serie::where('is_show', 1)
                                ->where('annee', $date)
                                ->orderBy('date_add_str', 'desc')
                                ->paginate(20, ['*'], 'page', $page);

        return view('serie.dateseries',['series' => $series,'date' => $date]);
    }
    
    public function alphabet($char, $page = 1){
        $series  = \App\Serie::where('is_show', 1)->where('titre', 'like', $char.'%')
                                ->orderBy('date_add_str', 'desc')
                                ->paginate(20, ['*'], 'page', $page);


        return view('serie.alphabet',['series' => $series, 'char' => $char]);
    }
    
    public function nombre($numb, $page = 1){
        $series  = \App\Serie::where('is_show', 1)->where('titre', 'like', $numb.'%')
                                ->orderBy('date_add_str', 'desc')
                                ->paginate(20, ['*'], 'page', $page);


        return view('serie.nombre',['series' => $series, 'numb' => $numb]);
    }
    
    public function hebergeur($server, $page = 1){
        $series  = \App\Serie::where('is_show', 1)
                                ->orderBy('date_add_str', 'desc')
                                ->paginate(20, ['*'], 'page', $page);


        return view('serie.hebergeur',['series' => $series, 'server' => $server]);
    }
    

}
