<?php

namespace App\Providers;

use Illuminate\Support\ServiceProvider;
use Illuminate\Support\Facades\View;
use Illuminate\Support\Facades\Cache;
use Carbon\Carbon;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        
        $genres_series = Cache::remember('genreSeriers', Carbon::now()->addDays(1), function () {
            return \App\Genre::withCount('serie_genres')->orderBy('serie_genres_count', 'desc')->limit(15)->get();
        });
        
        
        $genres_films = Cache::remember('genreFilms', Carbon::now()->addDays(1), function () {
            return \App\Genre::withCount('film_genres')->orderBy('film_genres_count', 'desc')->limit(15)->get();
        });
        
        

        View::share([
                    'genres_series' => $genres_series,
                    'genres_films' => $genres_films
                    ]);
    }

    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {
        if ($this->app->environment() !== 'production') {
            $this->app->register(\Sven\ArtisanView\ServiceProvider::class);
        }  
    }
}
